# McGSEA: Multi-condition Gene Set Enrichment Analysis

McGSEA extends fast Gene Set Enrichment Analysis (FGSEA) to handle multi-condition experiments with a high-performance C++ backend.

**This package is under active development. A full release is coming soon.**

## Links

- [Repository](https://github.com/transcriptabio/McGSEA)

## License

MIT License - Copyright (c) 2024 Transcripta Bio
